# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataset/v1/dataset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/dataset/v1/dataset.proto',
  package='github.com.metaprov.modelaapi.services.dataset.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/dataset/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/dataset/v1/dataset.proto\x12\x31github.com.metaprov.modelaapi.services.dataset.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xbb\x01\n\x13ListDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x14ListDatasetsResponse\x12S\n\x08\x64\x61tasets\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetList\"\xc5\x01\n\x11GetDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x12GetDatasetResponse\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"c\n\x14\x43reateDatasetRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x17\n\x15\x43reateDatasetResponse\"c\n\x14UpdateDatasetRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x17\n\x15UpdateDatasetResponse\"7\n\x14\x44\x65leteDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteDatasetResponse\"Q\n\x12UploadChunkRequest\x12\r\n\x05\x66name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x05\x12\x0c\n\x04last\x18\x04 \x01(\x08\"0\n\x13UploadChunkResponse\x12\r\n\x05\x66name\x18\x01 \x01(\t\x12\n\n\x02ok\x18\x02 \x01(\x08\"\x8b\x01\n\x1b\x43reateDatasetProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\x04item\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"~\n\x1c\x43reateDatasetProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12Q\n\x07profile\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\x97\x01\n\x1a\x43reateColumnProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x63ol\x18\x03 \x01(\t\x12K\n\x04item\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"q\n\x1b\x43reateColumnProfileResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x04plot\x18\x02 \x01(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\"H\n\x18GetDatasetProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x8f\x01\n\x19GetDatasetProfileResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\x07profile\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\":\n\x16\x43ompareDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"\x8f\x01\n\x17\x43ompareDatasetsResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12R\n\x08profiles\x18\x03 \x03(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\":\n\x16GenerateDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"\x8f\x01\n\x17GenerateDatasetResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12R\n\x08profiles\x18\x03 \x03(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\":\n\x16ValidateDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"\x8f\x01\n\x17ValidateDatasetResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12R\n\x08profiles\x18\x03 \x03(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"9\n\x16\x44ownloadDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"&\n\x17\x44ownloadDatasetResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"J\n\x13GetDatabasesRequest\x12\x1b\n\x13\x63onnectionNamespace\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\")\n\x14GetDatabasesResponse\x12\x11\n\tdatabases\x18\x01 \x03(\t\"]\n\x10GetTablesRequest\x12\x1b\n\x13\x63onnectionNamespace\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\"#\n\x11GetTablesResponse\x12\x0e\n\x06tables\x18\x01 \x03(\t\"k\n\x11\x45xecuteSqlRequest\x12\x1b\n\x13\x63onnectionNamespace\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x12\x0b\n\x03sql\x18\x04 \x01(\t\"d\n\x12\x45xecuteSqlResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"i\n\x0fSnapshotRequest\x12\x1b\n\x13\x63onnectionNamespace\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x12\x0b\n\x03sql\x18\x04 \x01(\t\"0\n\x10SnapshotResponse\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t2\x83\x1e\n\x0e\x44\x61tasetService\x12\xb9\x01\n\x0cListDatasets\x12\x46.github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest\x1aG.github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/datasets\x12\xba\x01\n\nGetDataset\x12\x44.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/datasets/{name}\x12\xc5\x01\n\rCreateDataset\x12G.github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetRequest\x1aH.github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x10/api/v1/datasets:\x07\x64\x61taset\x12\xdd\x01\n\rUpdateDataset\x12G.github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetRequest\x1aH.github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetResponse\"9\x82\xd3\xe4\x93\x02\x33\x1a(/api/v1/datasets/{dataset.metadata.name}:\x07\x64\x61taset\x12\xc3\x01\n\rDeleteDataset\x12G.github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetRequest\x1aH.github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetResponse\"\x1f\x82\xd3\xe4\x93\x02\x19*\x17/api/v1/datasets/{name}\x12\xff\x01\n\x0f\x43ompareDatasets\x12I.github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsRequest\x1aJ.github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsResponse\"U\x82\xd3\xe4\x93\x02O\"M/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:compare\x12\x85\x02\n\x11GetDatasetProfile\x12K.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileRequest\x1aL.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileResponse\"U\x82\xd3\xe4\x93\x02O\x12M/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:profile\x12\x8e\x02\n\x14\x43reateDatasetProfile\x12N.github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileRequest\x1aO.github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileResponse\"U\x82\xd3\xe4\x93\x02O\"M/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:profile\x12\x8e\x02\n\x13\x43reateColumnProfile\x12M.github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest\x1aN.github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileResponse\"X\x82\xd3\xe4\x93\x02R\"P/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}/columnplot\x12\x80\x02\n\x0fGenerateDataset\x12I.github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetRequest\x1aJ.github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetResponse\"V\x82\xd3\xe4\x93\x02P\"N/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:generate\x12\x80\x02\n\x0fValidateDataset\x12I.github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetRequest\x1aJ.github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetResponse\"V\x82\xd3\xe4\x93\x02P\"N/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:validate\x12\xf4\x01\n\x0bUploadChunk\x12\x45.github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkRequest\x1a\x46.github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkResponse\"V\x82\xd3\xe4\x93\x02P\"N/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:validate\x12\x80\x02\n\x0f\x44ownloadDataset\x12I.github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetRequest\x1aJ.github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetResponse\"V\x82\xd3\xe4\x93\x02P\"N/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:download\x12\xf8\x01\n\x0cGetDatabases\x12\x46.github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesRequest\x1aG.github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesResponse\"W\x82\xd3\xe4\x93\x02Q\x12O/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:databases\x12\xec\x01\n\tGetTables\x12\x43.github.com.metaprov.modelaapi.services.dataset.v1.GetTablesRequest\x1a\x44.github.com.metaprov.modelaapi.services.dataset.v1.GetTablesResponse\"T\x82\xd3\xe4\x93\x02N\x12L/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:tables\x12\xf3\x01\n\nExecuteSql\x12\x44.github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlResponse\"X\x82\xd3\xe4\x93\x02R\"P/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:executesqlB3Z1github.com/metaprov/modelaapi/services/dataset/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTDATASETSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=469,
)

_LISTDATASETSREQUEST = _descriptor.Descriptor(
  name='ListDatasetsRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDATASETSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=282,
  serialized_end=469,
)


_LISTDATASETSRESPONSE = _descriptor.Descriptor(
  name='ListDatasetsResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datasets', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsResponse.datasets', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=578,
)


_GETDATASETREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=469,
)

_GETDATASETREQUEST = _descriptor.Descriptor(
  name='GetDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETDATASETREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=778,
)


_GETDATASETRESPONSE = _descriptor.Descriptor(
  name='GetDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=891,
)


_CREATEDATASETREQUEST = _descriptor.Descriptor(
  name='CreateDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=992,
)


_CREATEDATASETRESPONSE = _descriptor.Descriptor(
  name='CreateDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1017,
)


_UPDATEDATASETREQUEST = _descriptor.Descriptor(
  name='UpdateDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1019,
  serialized_end=1118,
)


_UPDATEDATASETRESPONSE = _descriptor.Descriptor(
  name='UpdateDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1143,
)


_DELETEDATASETREQUEST = _descriptor.Descriptor(
  name='DeleteDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1145,
  serialized_end=1200,
)


_DELETEDATASETRESPONSE = _descriptor.Descriptor(
  name='DeleteDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1225,
)


_UPLOADCHUNKREQUEST = _descriptor.Descriptor(
  name='UploadChunkRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fname', full_name='github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkRequest.fname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkRequest.index', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last', full_name='github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkRequest.last', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1227,
  serialized_end=1308,
)


_UPLOADCHUNKRESPONSE = _descriptor.Descriptor(
  name='UploadChunkResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fname', full_name='github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkResponse.fname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ok', full_name='github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkResponse.ok', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1310,
  serialized_end=1358,
)


_CREATEDATASETPROFILEREQUEST = _descriptor.Descriptor(
  name='CreateDatasetProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileRequest.item', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1361,
  serialized_end=1500,
)


_CREATEDATASETPROFILERESPONSE = _descriptor.Descriptor(
  name='CreateDatasetProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileResponse.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileResponse.profile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1502,
  serialized_end=1628,
)


_CREATECOLUMNPROFILEREQUEST = _descriptor.Descriptor(
  name='CreateColumnProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='col', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest.col', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest.item', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1782,
)


_CREATECOLUMNPROFILERESPONSE = _descriptor.Descriptor(
  name='CreateColumnProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plot', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileResponse.plot', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1784,
  serialized_end=1897,
)


_GETDATASETPROFILEREQUEST = _descriptor.Descriptor(
  name='GetDatasetProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileRequest.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1899,
  serialized_end=1971,
)


_GETDATASETPROFILERESPONSE = _descriptor.Descriptor(
  name='GetDatasetProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileResponse.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileResponse.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileResponse.profile', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1974,
  serialized_end=2117,
)


_COMPAREDATASETSREQUEST = _descriptor.Descriptor(
  name='CompareDatasetsRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2119,
  serialized_end=2177,
)


_COMPAREDATASETSRESPONSE = _descriptor.Descriptor(
  name='CompareDatasetsResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsResponse.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsResponse.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profiles', full_name='github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsResponse.profiles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2180,
  serialized_end=2323,
)


_GENERATEDATASETREQUEST = _descriptor.Descriptor(
  name='GenerateDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2325,
  serialized_end=2383,
)


_GENERATEDATASETRESPONSE = _descriptor.Descriptor(
  name='GenerateDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetResponse.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetResponse.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profiles', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetResponse.profiles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2386,
  serialized_end=2529,
)


_VALIDATEDATASETREQUEST = _descriptor.Descriptor(
  name='ValidateDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetRequest.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2531,
  serialized_end=2589,
)


_VALIDATEDATASETRESPONSE = _descriptor.Descriptor(
  name='ValidateDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetResponse.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='names', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetResponse.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profiles', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetResponse.profiles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2592,
  serialized_end=2735,
)


_DOWNLOADDATASETREQUEST = _descriptor.Descriptor(
  name='DownloadDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2737,
  serialized_end=2794,
)


_DOWNLOADDATASETRESPONSE = _descriptor.Descriptor(
  name='DownloadDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetResponse.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2796,
  serialized_end=2834,
)


_GETDATABASESREQUEST = _descriptor.Descriptor(
  name='GetDatabasesRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connectionNamespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesRequest.connectionNamespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connectionName', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesRequest.connectionName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2836,
  serialized_end=2910,
)


_GETDATABASESRESPONSE = _descriptor.Descriptor(
  name='GetDatabasesResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesResponse.databases', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2912,
  serialized_end=2953,
)


_GETTABLESREQUEST = _descriptor.Descriptor(
  name='GetTablesRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connectionNamespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetTablesRequest.connectionNamespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connectionName', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetTablesRequest.connectionName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='databaseName', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetTablesRequest.databaseName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2955,
  serialized_end=3048,
)


_GETTABLESRESPONSE = _descriptor.Descriptor(
  name='GetTablesResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tables', full_name='github.com.metaprov.modelaapi.services.dataset.v1.GetTablesResponse.tables', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3050,
  serialized_end=3085,
)


_EXECUTESQLREQUEST = _descriptor.Descriptor(
  name='ExecuteSqlRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connectionNamespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest.connectionNamespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connectionName', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest.connectionName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='databaseName', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest.databaseName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sql', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest.sql', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3087,
  serialized_end=3194,
)


_EXECUTESQLRESPONSE = _descriptor.Descriptor(
  name='ExecuteSqlResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableview', full_name='github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlResponse.tableview', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3196,
  serialized_end=3296,
)


_SNAPSHOTREQUEST = _descriptor.Descriptor(
  name='SnapshotRequest',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.SnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connectionNamespace', full_name='github.com.metaprov.modelaapi.services.dataset.v1.SnapshotRequest.connectionNamespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connectionName', full_name='github.com.metaprov.modelaapi.services.dataset.v1.SnapshotRequest.connectionName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='databaseName', full_name='github.com.metaprov.modelaapi.services.dataset.v1.SnapshotRequest.databaseName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sql', full_name='github.com.metaprov.modelaapi.services.dataset.v1.SnapshotRequest.sql', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3298,
  serialized_end=3403,
)


_SNAPSHOTRESPONSE = _descriptor.Descriptor(
  name='SnapshotResponse',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.SnapshotResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.dataset.v1.SnapshotResponse.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.dataset.v1.SnapshotResponse.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3405,
  serialized_end=3453,
)

_LISTDATASETSREQUEST_LABELSENTRY.containing_type = _LISTDATASETSREQUEST
_LISTDATASETSREQUEST.fields_by_name['labels'].message_type = _LISTDATASETSREQUEST_LABELSENTRY
_LISTDATASETSRESPONSE.fields_by_name['datasets'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASETLIST
_GETDATASETREQUEST_LABELSENTRY.containing_type = _GETDATASETREQUEST
_GETDATASETREQUEST.fields_by_name['labels'].message_type = _GETDATASETREQUEST_LABELSENTRY
_GETDATASETRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATEDATASETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_UPDATEDATASETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATEDATASETPROFILEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATEDATASETPROFILERESPONSE.fields_by_name['profile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._DATASETPROFILE
_CREATECOLUMNPROFILEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATECOLUMNPROFILERESPONSE.fields_by_name['plot'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._PLOT
_GETDATASETPROFILERESPONSE.fields_by_name['profile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._DATASETPROFILE
_COMPAREDATASETSRESPONSE.fields_by_name['profiles'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._DATASETPROFILE
_GENERATEDATASETRESPONSE.fields_by_name['profiles'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._DATASETPROFILE
_VALIDATEDATASETRESPONSE.fields_by_name['profiles'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._DATASETPROFILE
_EXECUTESQLRESPONSE.fields_by_name['tableview'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._TABLEVIEW
DESCRIPTOR.message_types_by_name['ListDatasetsRequest'] = _LISTDATASETSREQUEST
DESCRIPTOR.message_types_by_name['ListDatasetsResponse'] = _LISTDATASETSRESPONSE
DESCRIPTOR.message_types_by_name['GetDatasetRequest'] = _GETDATASETREQUEST
DESCRIPTOR.message_types_by_name['GetDatasetResponse'] = _GETDATASETRESPONSE
DESCRIPTOR.message_types_by_name['CreateDatasetRequest'] = _CREATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['CreateDatasetResponse'] = _CREATEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDatasetRequest'] = _UPDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatasetResponse'] = _UPDATEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDatasetRequest'] = _DELETEDATASETREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatasetResponse'] = _DELETEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['UploadChunkRequest'] = _UPLOADCHUNKREQUEST
DESCRIPTOR.message_types_by_name['UploadChunkResponse'] = _UPLOADCHUNKRESPONSE
DESCRIPTOR.message_types_by_name['CreateDatasetProfileRequest'] = _CREATEDATASETPROFILEREQUEST
DESCRIPTOR.message_types_by_name['CreateDatasetProfileResponse'] = _CREATEDATASETPROFILERESPONSE
DESCRIPTOR.message_types_by_name['CreateColumnProfileRequest'] = _CREATECOLUMNPROFILEREQUEST
DESCRIPTOR.message_types_by_name['CreateColumnProfileResponse'] = _CREATECOLUMNPROFILERESPONSE
DESCRIPTOR.message_types_by_name['GetDatasetProfileRequest'] = _GETDATASETPROFILEREQUEST
DESCRIPTOR.message_types_by_name['GetDatasetProfileResponse'] = _GETDATASETPROFILERESPONSE
DESCRIPTOR.message_types_by_name['CompareDatasetsRequest'] = _COMPAREDATASETSREQUEST
DESCRIPTOR.message_types_by_name['CompareDatasetsResponse'] = _COMPAREDATASETSRESPONSE
DESCRIPTOR.message_types_by_name['GenerateDatasetRequest'] = _GENERATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['GenerateDatasetResponse'] = _GENERATEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['ValidateDatasetRequest'] = _VALIDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['ValidateDatasetResponse'] = _VALIDATEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['DownloadDatasetRequest'] = _DOWNLOADDATASETREQUEST
DESCRIPTOR.message_types_by_name['DownloadDatasetResponse'] = _DOWNLOADDATASETRESPONSE
DESCRIPTOR.message_types_by_name['GetDatabasesRequest'] = _GETDATABASESREQUEST
DESCRIPTOR.message_types_by_name['GetDatabasesResponse'] = _GETDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['GetTablesRequest'] = _GETTABLESREQUEST
DESCRIPTOR.message_types_by_name['GetTablesResponse'] = _GETTABLESRESPONSE
DESCRIPTOR.message_types_by_name['ExecuteSqlRequest'] = _EXECUTESQLREQUEST
DESCRIPTOR.message_types_by_name['ExecuteSqlResponse'] = _EXECUTESQLRESPONSE
DESCRIPTOR.message_types_by_name['SnapshotRequest'] = _SNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name['SnapshotResponse'] = _SNAPSHOTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListDatasetsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATASETSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest)
  })
_sym_db.RegisterMessage(ListDatasetsRequest)
_sym_db.RegisterMessage(ListDatasetsRequest.LabelsEntry)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsResponse)
  })
_sym_db.RegisterMessage(ListDatasetsResponse)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType('GetDatasetRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETDATASETREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest)
  })
_sym_db.RegisterMessage(GetDatasetRequest)
_sym_db.RegisterMessage(GetDatasetRequest.LabelsEntry)

GetDatasetResponse = _reflection.GeneratedProtocolMessageType('GetDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetResponse)
  })
_sym_db.RegisterMessage(GetDatasetResponse)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetRequest)
  })
_sym_db.RegisterMessage(CreateDatasetRequest)

CreateDatasetResponse = _reflection.GeneratedProtocolMessageType('CreateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetResponse)
  })
_sym_db.RegisterMessage(CreateDatasetResponse)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetRequest)
  })
_sym_db.RegisterMessage(UpdateDatasetRequest)

UpdateDatasetResponse = _reflection.GeneratedProtocolMessageType('UpdateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetResponse)
  })
_sym_db.RegisterMessage(UpdateDatasetResponse)

DeleteDatasetRequest = _reflection.GeneratedProtocolMessageType('DeleteDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetRequest)
  })
_sym_db.RegisterMessage(DeleteDatasetRequest)

DeleteDatasetResponse = _reflection.GeneratedProtocolMessageType('DeleteDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetResponse)
  })
_sym_db.RegisterMessage(DeleteDatasetResponse)

UploadChunkRequest = _reflection.GeneratedProtocolMessageType('UploadChunkRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADCHUNKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkRequest)
  })
_sym_db.RegisterMessage(UploadChunkRequest)

UploadChunkResponse = _reflection.GeneratedProtocolMessageType('UploadChunkResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADCHUNKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkResponse)
  })
_sym_db.RegisterMessage(UploadChunkResponse)

CreateDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileRequest)
  })
_sym_db.RegisterMessage(CreateDatasetProfileRequest)

CreateDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('CreateDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileResponse)
  })
_sym_db.RegisterMessage(CreateDatasetProfileResponse)

CreateColumnProfileRequest = _reflection.GeneratedProtocolMessageType('CreateColumnProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLUMNPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest)
  })
_sym_db.RegisterMessage(CreateColumnProfileRequest)

CreateColumnProfileResponse = _reflection.GeneratedProtocolMessageType('CreateColumnProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLUMNPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileResponse)
  })
_sym_db.RegisterMessage(CreateColumnProfileResponse)

GetDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('GetDatasetProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileRequest)
  })
_sym_db.RegisterMessage(GetDatasetProfileRequest)

GetDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('GetDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileResponse)
  })
_sym_db.RegisterMessage(GetDatasetProfileResponse)

CompareDatasetsRequest = _reflection.GeneratedProtocolMessageType('CompareDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsRequest)
  })
_sym_db.RegisterMessage(CompareDatasetsRequest)

CompareDatasetsResponse = _reflection.GeneratedProtocolMessageType('CompareDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsResponse)
  })
_sym_db.RegisterMessage(CompareDatasetsResponse)

GenerateDatasetRequest = _reflection.GeneratedProtocolMessageType('GenerateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetRequest)
  })
_sym_db.RegisterMessage(GenerateDatasetRequest)

GenerateDatasetResponse = _reflection.GeneratedProtocolMessageType('GenerateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetResponse)
  })
_sym_db.RegisterMessage(GenerateDatasetResponse)

ValidateDatasetRequest = _reflection.GeneratedProtocolMessageType('ValidateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetRequest)
  })
_sym_db.RegisterMessage(ValidateDatasetRequest)

ValidateDatasetResponse = _reflection.GeneratedProtocolMessageType('ValidateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetResponse)
  })
_sym_db.RegisterMessage(ValidateDatasetResponse)

DownloadDatasetRequest = _reflection.GeneratedProtocolMessageType('DownloadDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetRequest)
  })
_sym_db.RegisterMessage(DownloadDatasetRequest)

DownloadDatasetResponse = _reflection.GeneratedProtocolMessageType('DownloadDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetResponse)
  })
_sym_db.RegisterMessage(DownloadDatasetResponse)

GetDatabasesRequest = _reflection.GeneratedProtocolMessageType('GetDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesRequest)
  })
_sym_db.RegisterMessage(GetDatabasesRequest)

GetDatabasesResponse = _reflection.GeneratedProtocolMessageType('GetDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesResponse)
  })
_sym_db.RegisterMessage(GetDatabasesResponse)

GetTablesRequest = _reflection.GeneratedProtocolMessageType('GetTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetTablesRequest)
  })
_sym_db.RegisterMessage(GetTablesRequest)

GetTablesResponse = _reflection.GeneratedProtocolMessageType('GetTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetTablesResponse)
  })
_sym_db.RegisterMessage(GetTablesResponse)

ExecuteSqlRequest = _reflection.GeneratedProtocolMessageType('ExecuteSqlRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESQLREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest)
  })
_sym_db.RegisterMessage(ExecuteSqlRequest)

ExecuteSqlResponse = _reflection.GeneratedProtocolMessageType('ExecuteSqlResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESQLRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlResponse)
  })
_sym_db.RegisterMessage(ExecuteSqlResponse)

SnapshotRequest = _reflection.GeneratedProtocolMessageType('SnapshotRequest', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.SnapshotRequest)
  })
_sym_db.RegisterMessage(SnapshotRequest)

SnapshotResponse = _reflection.GeneratedProtocolMessageType('SnapshotResponse', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.SnapshotResponse)
  })
_sym_db.RegisterMessage(SnapshotResponse)


DESCRIPTOR._options = None
_LISTDATASETSREQUEST_LABELSENTRY._options = None
_GETDATASETREQUEST_LABELSENTRY._options = None

_DATASETSERVICE = _descriptor.ServiceDescriptor(
  name='DatasetService',
  full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3456,
  serialized_end=7299,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDatasets',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.ListDatasets',
    index=0,
    containing_service=None,
    input_type=_LISTDATASETSREQUEST,
    output_type=_LISTDATASETSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/api/v1/datasets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataset',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.GetDataset',
    index=1,
    containing_service=None,
    input_type=_GETDATASETREQUEST,
    output_type=_GETDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/api/v1/datasets/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataset',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.CreateDataset',
    index=2,
    containing_service=None,
    input_type=_CREATEDATASETREQUEST,
    output_type=_CREATEDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\"\020/api/v1/datasets:\007dataset',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataset',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.UpdateDataset',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATASETREQUEST,
    output_type=_UPDATEDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\0023\032(/api/v1/datasets/{dataset.metadata.name}:\007dataset',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataset',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.DeleteDataset',
    index=4,
    containing_service=None,
    input_type=_DELETEDATASETREQUEST,
    output_type=_DELETEDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002\031*\027/api/v1/datasets/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CompareDatasets',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.CompareDatasets',
    index=5,
    containing_service=None,
    input_type=_COMPAREDATASETSREQUEST,
    output_type=_COMPAREDATASETSRESPONSE,
    serialized_options=b'\202\323\344\223\002O\"M/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:compare',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDatasetProfile',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.GetDatasetProfile',
    index=6,
    containing_service=None,
    input_type=_GETDATASETPROFILEREQUEST,
    output_type=_GETDATASETPROFILERESPONSE,
    serialized_options=b'\202\323\344\223\002O\022M/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDatasetProfile',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.CreateDatasetProfile',
    index=7,
    containing_service=None,
    input_type=_CREATEDATASETPROFILEREQUEST,
    output_type=_CREATEDATASETPROFILERESPONSE,
    serialized_options=b'\202\323\344\223\002O\"M/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateColumnProfile',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.CreateColumnProfile',
    index=8,
    containing_service=None,
    input_type=_CREATECOLUMNPROFILEREQUEST,
    output_type=_CREATECOLUMNPROFILERESPONSE,
    serialized_options=b'\202\323\344\223\002R\"P/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}/columnplot',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateDataset',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.GenerateDataset',
    index=9,
    containing_service=None,
    input_type=_GENERATEDATASETREQUEST,
    output_type=_GENERATEDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002P\"N/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:generate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateDataset',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.ValidateDataset',
    index=10,
    containing_service=None,
    input_type=_VALIDATEDATASETREQUEST,
    output_type=_VALIDATEDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002P\"N/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:validate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UploadChunk',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.UploadChunk',
    index=11,
    containing_service=None,
    input_type=_UPLOADCHUNKREQUEST,
    output_type=_UPLOADCHUNKRESPONSE,
    serialized_options=b'\202\323\344\223\002P\"N/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:validate',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadDataset',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.DownloadDataset',
    index=12,
    containing_service=None,
    input_type=_DOWNLOADDATASETREQUEST,
    output_type=_DOWNLOADDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002P\"N/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:download',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDatabases',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.GetDatabases',
    index=13,
    containing_service=None,
    input_type=_GETDATABASESREQUEST,
    output_type=_GETDATABASESRESPONSE,
    serialized_options=b'\202\323\344\223\002Q\022O/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:databases',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTables',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.GetTables',
    index=14,
    containing_service=None,
    input_type=_GETTABLESREQUEST,
    output_type=_GETTABLESRESPONSE,
    serialized_options=b'\202\323\344\223\002N\022L/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:tables',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteSql',
    full_name='github.com.metaprov.modelaapi.services.dataset.v1.DatasetService.ExecuteSql',
    index=15,
    containing_service=None,
    input_type=_EXECUTESQLREQUEST,
    output_type=_EXECUTESQLRESPONSE,
    serialized_options=b'\202\323\344\223\002R\"P/api/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:executesql',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASETSERVICE)

DESCRIPTOR.services_by_name['DatasetService'] = _DATASETSERVICE

# @@protoc_insertion_point(module_scope)
